/* Created 27 November 2010.

This file uses the data departement_level.dta and runs the departement-level regressions for 
"Marrying Up: The role of sex ratio in assortative matching".
*/

#delimit ;

* set this folder path to the directory that contains the file departement_level.dta;
local folder "~/Documents";

version 11.1;
set more off;
clear all;
cd "`folder'";
set matsize 800;
set memory 40M;
capture log close;
log using departement_level.log, replace;



*************************************************************************************;
* Table A1 summary statistics 
*************************************************************************************;

use departement_level, clear;

bys post: sum mortality sr singm_19 singm_29d singm_39d singm_49d singf_19 singf_29d singf_39d singf_49d 
	divm_29d divm_39d divm_49d divf_29d divf_39d divf_49d widm_29d widm_39d widm_49d widf_29d widf_39d 
	widf_49d illeg;



*************************************************************************************;
* Table 2: The impact of male scarcity on marital status by age group and gender  
*************************************************************************************;

gen post_mortality = post*mortality;

* column 1 of Table 2;
di _n "Single males aged 15-19";
xi: reg singm_19 post_mortality post i.depc;
di _n "Single males aged 20-29";
xi: reg singm_29d post_mortality post i.depc;
di _n "Single males aged 30-39";
xi: reg singm_39d post_mortality post i.depc;
di _n "Single males aged 40-49";
xi: reg singm_49d post_mortality post i.depc;

* column 2 of Table 2;
di _n "Single females aged 15-19";
xi: reg singf_19 post_mortality post i.depc;
di _n "Single females aged 20-29";
xi: reg singf_29d post_mortality post i.depc;
di _n "Single females aged 30-39";
xi: reg singf_39d post_mortality post i.depc;
di _n "Single females aged 40-49";
xi: reg singf_49d post_mortality post i.depc;

* column 3 of Table 2;
di _n "Divorced males aged 20-29";
xi: reg divm_29d post_mortality post i.depc;
di _n "Divorced males aged 30-39";
xi: reg divm_39d post_mortality post i.depc;
di _n "Divorced males aged 40-49";
xi: reg divm_49d post_mortality post i.depc;

* column 4 of Table 2;
di _n "Divorced females aged 20-29";
xi: reg divf_29d post_mortality post i.depc;
di _n "Divorced females aged 30-39";
xi: reg divf_39d post_mortality post i.depc;
di _n "Divorced females aged 40-49";
xi: reg divf_49d post_mortality post i.depc;

* column 5 of Table 2;
di _n "Widowed males aged 20-29";
xi: reg widm_29d post_mortality post i.depc;
di _n "Widowed males aged 30-39";
xi: reg widm_39d post_mortality post i.depc;
di _n "Widowed males aged 40-49";
xi: reg widm_49d post_mortality post i.depc;

* column 6 of Table 2;
di _n "Widowed females aged 20-29";
xi: reg widf_29d post_mortality post i.depc;
di _n "Widowed females aged 30-39";
xi: reg widf_39d post_mortality post i.depc;
di _n "Widowed females aged 40-49";
xi: reg widf_49d post_mortality post i.depc;













